@@ -1,7 +1,11 @@
+#
+# Minimal CONNECT proxy server for debugging
+#
+#   $ HTTPS_PROXY=http://127.0.0.1:3000 mojo get https://mojolicious.org
+#
 use Mojo::Base -strict;
 use Mojo::IOLoop;
 
-# Minimal CONNECT proxy server to test TLS tunneling
 my %buffer;
 Mojo::IOLoop->server(
   {port => 3000} => sub {
@@ -74,11 +78,7 @@ Mojo::IOLoop->server(
   }
 );
 
-print <<'EOF';
-Starting CONNECT proxy on port 3000.
-For testing use something like "HTTPS_PROXY=http://127.0.0.1:3000".
-EOF
-
+print "Starting CONNECT proxy on port 3000.\n";
 Mojo::IOLoop->start;
 
 1;
