@@ -5,6 +5,7 @@ use Carp 'croak';
 use Exporter 'import';
 use List::Util;
 use Mojo::ByteStream;
+use Mojo::Util 'deprecated';
 use Scalar::Util 'blessed';
 
 our @EXPORT_OK = ('c');
@@ -69,7 +70,9 @@ sub shuffle { $_[0]->new(List::Util::shuffle @{$_[0]}) }
 
 sub size { scalar @{$_[0]} }
 
+# DEPRECATED!
 sub slice {
+  deprecated 'Mojo::Collection::slice is DEPRECATED';
   my $self = shift;
   return $self->new(@$self[@_]);
 }
@@ -96,7 +99,7 @@ sub uniq {
   my ($self, $cb) = (shift, shift);
   my %seen;
   return $self->new(grep { !$seen{$_->$cb(@_) // ''}++ } @$self) if $cb;
-  return $self->new(grep { !$seen{$_ // ''}++ } @$self);
+  return $self->new(grep { !$seen{$_          // ''}++ } @$self);
 }
 
 sub with_roles { shift->Mojo::Base::with_roles(@_) }
@@ -304,15 +307,6 @@ C<$b> will always be set to the next element in the collection.
 
 Create a new collection with all elements in reverse order.
 
-=head2 slice
-
-  my $new = $collection->slice(4 .. 7);
-
-Create a new collection with all selected elements.
-
-  # "B C E"
-  c('A', 'B', 'C', 'D', 'E')->slice(1, 2, 4)->join(' ');
-
 =head2 shuffle
 
   my $new = $collection->shuffle;
@@ -380,6 +374,6 @@ Alias for L<Mojo::Base/"with_roles">.
 
 =head1 SEE ALSO
 
-L<Mojolicious>, L<Mojolicious::Guides>, L<http://mojolicious.org>.
+L<Mojolicious>, L<Mojolicious::Guides>, L<https://mojolicious.org>.
 
 =cut
