@@ -244,8 +244,8 @@ L<Mojo::IOLoop::Stream> implements the following attributes.
   $msg     = $msg->high_water_mark(1024);
 
 Maximum size of L</"write"> buffer in bytes before L</"can_write"> returns
-false, defaults to C<1048576> (1MiB). Note that this attribute is EXPERIMENTAL
-and might change without warning!
+false, defaults to C<1048576> (1MiB). Note that this attribute is
+B<EXPERIMENTAL> and might change without warning!
 
 =head2 reactor
 
@@ -271,7 +271,8 @@ Number of bytes received.
   my $num = $stream->bytes_waiting;
 
 Number of bytes that have been enqueued with L</"write"> and are waiting to be
-written. Note that this method is EXPERIMENTAL and might change without warning!
+written. Note that this method is B<EXPERIMENTAL> and might change without
+warning!
 
 =head2 bytes_written
 
@@ -284,7 +285,7 @@ Number of bytes written.
   my $bool = $stream->can_write;
 
 Returns true if calling L</"write"> is safe. Note that this method is
-EXPERIMENTAL and might change without warning!
+B<EXPERIMENTAL> and might change without warning!
 
 =head2 close
 
